==> cmocka-doc-2.0.0-1-x86_64.tar.xz: usr/share/doc/cmocka/html/search/all_1.js <==
var searchData=
[
  ['call_20ordering_0',['🔢 Call Ordering',['../group__cmocka__call__order.html',1,'']]],
  ['cast_5fint_5fto_5fcmocka_5fvalue_1',['cast_int_to_cmocka_value',['../group__cmocka__util.html#ga5f28193c4aebb48df2daea39b94d52b2',1,'cmocka.h']]],
  ['cast_5fptr_5fto_5fcmocka_5fvalue_2',['cast_ptr_to_cmocka_value',['../group__cmocka__util.html#gaa8f3c70bdf75be1901e1aa20486d38fb',1,'cmocka.h']]],
  ['cast_5fto_5fvoid_5fpointer_3',['cast_to_void_pointer',['../group__cmocka__util.html#gaed06a140efb4449855ade3b1f1fd4beb',1,'cmocka.h']]],
  ['check_20example_4',['Version Check Example',['../group__cmocka__version.html#autotoc_md5',1,'']]],
  ['check_5fexpected_5',['check_expected',['../group__cmocka__param.html#ga2788d04a9ae39c595d4c6189db7db1af',1,'cmocka.h']]],
  ['check_5fexpected_5fany_6',['check_expected_any',['../group__cmocka__param.html#gad50eeae9043643c3328489b583b0ba1b',1,'cmocka.h']]],
  ['check_5fexpected_5fdouble_7',['check_expected_double',['../group__cmocka__param.html#ga84451e70567c56228e85d42623ada0f9',1,'cmocka.h']]],
  ['check_5fexpected_5ffloat_8',['check_expected_float',['../group__cmocka__param.html#ga5a0783e0a760c924e0a871bfe1cf0841',1,'cmocka.h']]],
  ['check_5fexpected_5fint_9',['check_expected_int',['../group__cmocka__param.html#ga7f126f5e39658c64d78a1216151d763c',1,'cmocka.h']]],
  ['check_5fexpected_5fptr_10',['check_expected_ptr',['../group__cmocka__param.html#ga151f50163b3cbec97759ae9b199031a9',1,'cmocka.h']]],
  ['check_5fexpected_5fuint_11',['check_expected_uint',['../group__cmocka__param.html#ga9620e9c278db3cd09c61690181178e0b',1,'cmocka.h']]],
  ['check_5ffloat_12',['check_float',['../structcheck__float.html',1,'']]],
  ['check_5ffloat_5fset_13',['check_float_set',['../structcheck__float__set.html',1,'']]],
  ['check_5finteger_5frange_14',['check_integer_range',['../structcheck__integer__range.html',1,'']]],
  ['check_5finteger_5fset_15',['check_integer_set',['../structcheck__integer__set.html',1,'']]],
  ['check_5funsigned_5finteger_5frange_16',['check_unsigned_integer_range',['../structcheck__unsigned__integer__range.html',1,'']]],
  ['check_5funsigned_5finteger_5fset_17',['check_unsigned_integer_set',['../structcheck__unsigned__integer__set.html',1,'']]],
  ['checker_20function_20interface_18',['Checker Function Interface',['../group__cmocka__param.html#autotoc_md0',1,'']]],
  ['checkfloat_19',['CheckFloat',['../struct_check_float.html',1,'']]],
  ['checkfloatrange_20',['CheckFloatRange',['../struct_check_float_range.html',1,'']]],
  ['checkfloatset_21',['CheckFloatSet',['../struct_check_float_set.html',1,'']]],
  ['checking_20parameters_22',['✅ Checking Parameters',['../group__cmocka__param.html',1,'']]],
  ['checkintegerrange_23',['CheckIntegerRange',['../struct_check_integer_range.html',1,'']]],
  ['checkintegerset_24',['CheckIntegerSet',['../struct_check_integer_set.html',1,'']]],
  ['checkintparametervalue_25',['CheckIntParameterValue',['../group__cmocka__param.html#ga84cba9aa0b8b3024b878c15e2cac200f',1,'cmocka.h']]],
  ['checkmemorydata_26',['CheckMemoryData',['../struct_check_memory_data.html',1,'']]],
  ['checkparameterevent_27',['CheckParameterEvent',['../struct_check_parameter_event.html',1,'CheckParameterEvent'],['../group__cmocka__param.html#ga86484031696fb3117b0fb313c3f2f481',1,'CheckParameterEvent:&#160;cmocka.h']]],
  ['checkparametereventdata_28',['CheckParameterEventData',['../struct_check_parameter_event_data.html',1,'CheckParameterEventData'],['../group__cmocka__param.html#gaf3415897eec4e9d902ceacf54fffb2bd',1,'CheckParameterEventData:&#160;cmocka.h']]],
  ['checkparametervalue_29',['CheckParameterValue',['../group__cmocka__param.html#ga7e8afd24ae620cf3e027c3989de1d980',1,'cmocka.h']]],
  ['checkparametervaluedata_30',['CheckParameterValueData',['../group__cmocka__param.html#ga8e202c9e430ad3a9e3668391c245eace',1,'cmocka.h']]],
  ['checkuintparametervalue_31',['CheckUintParameterValue',['../group__cmocka__param.html#gad0f0e130049219ecaec6afbcf4fac316',1,'cmocka.h']]],
  ['cm_5fmessage_5foutput_32',['cm_message_output',['../group__cmocka__config.html#gab0bc6b8252e7840ff5738477dc7a97ca',1,'cmocka.h']]],
  ['cm_5foutput_5fstandard_33',['CM_OUTPUT_STANDARD',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caa3523af79b68ef0b8e36eb14d207b9e5d',1,'cmocka.h']]],
  ['cm_5foutput_5fstdout_34',['CM_OUTPUT_STDOUT',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caa077feefe8f66dc3c9f62a3c3e0e07701',1,'cmocka.h']]],
  ['cm_5foutput_5fsubunit_35',['CM_OUTPUT_SUBUNIT',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caa18a2c2a9af66432cf04bf946c7ff9a04',1,'cmocka.h']]],
  ['cm_5foutput_5ftap_36',['CM_OUTPUT_TAP',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caa0504d2b39e4b3114844df1d56212ddb6',1,'cmocka.h']]],
  ['cm_5foutput_5fxml_37',['CM_OUTPUT_XML',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caaff2747e671915bc8ef0a018d4b1f243f',1,'cmocka.h']]],
  ['cm_5fprint_5ferror_38',['cm_print_error',['../group__cmocka__config.html#ga5283947dd5e907db7e49e06f27e522c6',1,'cmocka.h']]],
  ['cmcallbacks_39',['CMCallbacks',['../struct_c_m_callbacks.html',1,'']]],
  ['cmfixturefunction_40',['CMFixtureFunction',['../group__cmocka__exec.html#ga6d6219d951a8dd87760353943f045a25',1,'cmocka.h']]],
  ['cmocka_41',['cmocka',['../index.html',1,'']]],
  ['cmocka_20api_42',['📚 The CMocka API',['../group__cmocka.html',1,'']]],
  ['cmocka_20test_43',['A cmocka test',['../index.html#main-test',1,'']]],
  ['cmocka_5fprint_5ferror_44',['cmocka_print_error',['../group__cmocka__config.html#ga72a6204f0ed5d44f2d17b3b0169281b2',1,'cmocka.h']]],
  ['cmocka_5frun_5fgroup_5ftests_45',['cmocka_run_group_tests',['../group__cmocka__exec.html#ga7c62fd0acf2235ce98268c28ee262a57',1,'cmocka.h']]],
  ['cmocka_5frun_5fgroup_5ftests_5fname_46',['cmocka_run_group_tests_name',['../group__cmocka__exec.html#gae9d5f9af521ba6828081ea3014427569',1,'cmocka.h']]],
  ['cmocka_5fset_5fcallbacks_47',['cmocka_set_callbacks',['../group__cmocka__config.html#ga64d0bfeb072aa6735fad5db295f24f29',1,'cmocka_set_callbacks(const struct CMCallbacks *f_callbacks):&#160;cmocka.c'],['../group__cmocka__config.html#ga64d0bfeb072aa6735fad5db295f24f29',1,'cmocka_set_callbacks(const struct CMCallbacks *f_callbacks):&#160;cmocka.c']]],
  ['cmocka_5fset_5fmessage_5foutput_48',['cmocka_set_message_output',['../group__cmocka__config.html#ga003469ffcfe585b9cd058d18ba9a2971',1,'cmocka_set_message_output(uint32_t output):&#160;cmocka.c'],['../group__cmocka__config.html#ga003469ffcfe585b9cd058d18ba9a2971',1,'cmocka_set_message_output(uint32_t output):&#160;cmocka.c']]],
  ['cmocka_5fset_5fskip_5ffilter_49',['cmocka_set_skip_filter',['../group__cmocka__config.html#gac3994cdf617401dee7b0923503621072',1,'cmocka_set_skip_filter(const char *pattern):&#160;cmocka.c'],['../group__cmocka__config.html#gac3994cdf617401dee7b0923503621072',1,'cmocka_set_skip_filter(const char *pattern):&#160;cmocka.c']]],
  ['cmocka_5fset_5ftest_5ffilter_50',['cmocka_set_test_filter',['../group__cmocka__config.html#gad5006b3adbbe8962a57579f1d182a3b8',1,'cmocka_set_test_filter(const char *pattern):&#160;cmocka.c'],['../group__cmocka__config.html#gad5006b3adbbe8962a57579f1d182a3b8',1,'cmocka_set_test_filter(const char *pattern):&#160;cmocka.c']]],
  ['cmocka_5funit_5ftest_51',['cmocka_unit_test',['../group__cmocka__exec.html#ga562719c550b5ce277aab6b0371f7f34f',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fprestate_52',['cmocka_unit_test_prestate',['../group__cmocka__exec.html#ga4d54508b0b7150afb27b4da38f0015c6',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fprestate_5fsetup_5fteardown_53',['cmocka_unit_test_prestate_setup_teardown',['../group__cmocka__exec.html#ga07ea44503d0f6c84c460b4a878cf31d5',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fsetup_54',['cmocka_unit_test_setup',['../group__cmocka__exec.html#gaaccacc105038e49462888a3ededa28c5',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fsetup_5fteardown_55',['cmocka_unit_test_setup_teardown',['../group__cmocka__exec.html#gab9e5396c9a424ccbb5d30e6d421fd066',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fteardown_56',['cmocka_unit_test_teardown',['../group__cmocka__exec.html#ga9b0d5ed78ddeba6d9aaa9a692cda426b',1,'cmocka.h']]],
  ['cmocka_5fversion_57',['CMOCKA_VERSION',['../group__cmocka__version.html#ga900c8ec8466f621a1a19a497eb532aba',1,'cmocka_version.h']]],
  ['cmocka_5fversion_5fint_58',['CMOCKA_VERSION_INT',['../group__cmocka__version.html#gac343098e82585199ce9ec9d20ce64efb',1,'cmocka_version.h']]],
  ['cmocka_5fversion_5fmajor_59',['CMOCKA_VERSION_MAJOR',['../group__cmocka__version.html#ga28751152cf4d96d93bb60011a049641f',1,'cmocka_version.h']]],
  ['cmocka_5fversion_5fmicro_60',['CMOCKA_VERSION_MICRO',['../group__cmocka__version.html#ga047fa873bfb3978348f2fb1c02e18a24',1,'cmocka_version.h']]],
  ['cmocka_5fversion_5fminor_61',['CMOCKA_VERSION_MINOR',['../group__cmocka__version.html#ga74bb0bea61e3f4d68ea1dbe9afb640e4',1,'cmocka_version.h']]],
  ['cmockavaluedata_62',['CMockaValueData',['../group__cmocka__param.html#autotoc_md3',1,'Accessing Values in CMockaValueData'],['../union_c_mocka_value_data.html',1,'CMockaValueData']]],
  ['cmunittest_63',['CMUnitTest',['../struct_c_m_unit_test.html',1,'']]],
  ['cmunittestfunction_64',['CMUnitTestFunction',['../group__cmocka__exec.html#gaf7ec001f0be4727694546526a804c18c',1,'cmocka.h']]],
  ['cmunitteststate_65',['CMUnitTestState',['../struct_c_m_unit_test_state.html',1,'']]],
  ['configuration_20and_20output_66',['🔧 Configuration and Output',['../group__cmocka__config.html',1,'']]]
];

==> cmocka-doc-2.0.1-1-x86_64.tar.xz: usr/share/doc/cmocka/html/search/all_1.js <==
var searchData=
[
  ['call_20ordering_0',['🔢 Call Ordering',['../group__cmocka__call__order.html',1,'']]],
  ['cast_5fint_5fto_5fcmocka_5fvalue_1',['cast_int_to_cmocka_value',['../group__cmocka__util.html#ga5f28193c4aebb48df2daea39b94d52b2',1,'cmocka.h']]],
  ['cast_5fptr_5fto_5fcmocka_5fvalue_2',['cast_ptr_to_cmocka_value',['../group__cmocka__util.html#gaa8f3c70bdf75be1901e1aa20486d38fb',1,'cmocka.h']]],
  ['cast_5fto_5fvoid_5fpointer_3',['cast_to_void_pointer',['../group__cmocka__util.html#gaed06a140efb4449855ade3b1f1fd4beb',1,'cmocka.h']]],
  ['check_20example_4',['Version Check Example',['../group__cmocka__version.html#autotoc_md5',1,'']]],
  ['check_5fexpected_5',['check_expected',['../group__cmocka__param.html#ga2788d04a9ae39c595d4c6189db7db1af',1,'cmocka.h']]],
  ['check_5fexpected_5fany_6',['check_expected_any',['../group__cmocka__param.html#gad50eeae9043643c3328489b583b0ba1b',1,'cmocka.h']]],
  ['check_5fexpected_5fdouble_7',['check_expected_double',['../group__cmocka__param.html#ga84451e70567c56228e85d42623ada0f9',1,'cmocka.h']]],
  ['check_5fexpected_5ffloat_8',['check_expected_float',['../group__cmocka__param.html#ga5a0783e0a760c924e0a871bfe1cf0841',1,'cmocka.h']]],
  ['check_5fexpected_5fint_9',['check_expected_int',['../group__cmocka__param.html#ga7f126f5e39658c64d78a1216151d763c',1,'cmocka.h']]],
  ['check_5fexpected_5fptr_10',['check_expected_ptr',['../group__cmocka__param.html#ga151f50163b3cbec97759ae9b199031a9',1,'cmocka.h']]],
  ['check_5fexpected_5fuint_11',['check_expected_uint',['../group__cmocka__param.html#ga9620e9c278db3cd09c61690181178e0b',1,'cmocka.h']]],
  ['check_5ffloat_12',['check_float',['../structcheck__float.html',1,'']]],
  ['check_5ffloat_5fset_13',['check_float_set',['../structcheck__float__set.html',1,'']]],
  ['check_5finteger_5frange_14',['check_integer_range',['../structcheck__integer__range.html',1,'']]],
  ['check_5finteger_5fset_15',['check_integer_set',['../structcheck__integer__set.html',1,'']]],
  ['check_5funsigned_5finteger_5frange_16',['check_unsigned_integer_range',['../structcheck__unsigned__integer__range.html',1,'']]],
  ['check_5funsigned_5finteger_5fset_17',['check_unsigned_integer_set',['../structcheck__unsigned__integer__set.html',1,'']]],
  ['checker_20function_20interface_18',['Checker Function Interface',['../group__cmocka__param.html#autotoc_md0',1,'']]],
  ['checkfloat_19',['CheckFloat',['../struct_check_float.html',1,'']]],
  ['checkfloatrange_20',['CheckFloatRange',['../struct_check_float_range.html',1,'']]],
  ['checkfloatset_21',['CheckFloatSet',['../struct_check_float_set.html',1,'']]],
  ['checking_20parameters_22',['✅ Checking Parameters',['../group__cmocka__param.html',1,'']]],
  ['checkintegerrange_23',['CheckIntegerRange',['../struct_check_integer_range.html',1,'']]],
  ['checkintegerset_24',['CheckIntegerSet',['../struct_check_integer_set.html',1,'']]],
  ['checkintparametervalue_25',['CheckIntParameterValue',['../group__cmocka__param.html#ga84cba9aa0b8b3024b878c15e2cac200f',1,'cmocka.h']]],
  ['checkmemorydata_26',['CheckMemoryData',['../struct_check_memory_data.html',1,'']]],
  ['checkparameterevent_27',['CheckParameterEvent',['../struct_check_parameter_event.html',1,'CheckParameterEvent'],['../group__cmocka__param.html#ga86484031696fb3117b0fb313c3f2f481',1,'CheckParameterEvent:&#160;cmocka.h']]],
  ['checkparametereventdata_28',['CheckParameterEventData',['../struct_check_parameter_event_data.html',1,'CheckParameterEventData'],['../group__cmocka__param.html#gaf3415897eec4e9d902ceacf54fffb2bd',1,'CheckParameterEventData:&#160;cmocka.h']]],
  ['checkparametervalue_29',['CheckParameterValue',['../group__cmocka__param.html#ga7e8afd24ae620cf3e027c3989de1d980',1,'cmocka.h']]],
  ['checkparametervaluedata_30',['CheckParameterValueData',['../group__cmocka__param.html#ga8e202c9e430ad3a9e3668391c245eace',1,'cmocka.h']]],
  ['checkuintparametervalue_31',['CheckUintParameterValue',['../group__cmocka__param.html#gad0f0e130049219ecaec6afbcf4fac316',1,'cmocka.h']]],
  ['cm_5fmessage_5foutput_32',['cm_message_output',['../group__cmocka__config.html#gab0bc6b8252e7840ff5738477dc7a97ca',1,'cmocka.h']]],
  ['cm_5foutput_5fstandard_33',['CM_OUTPUT_STANDARD',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caa3523af79b68ef0b8e36eb14d207b9e5d',1,'cmocka.h']]],
  ['cm_5foutput_5fstdout_34',['CM_OUTPUT_STDOUT',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caa077feefe8f66dc3c9f62a3c3e0e07701',1,'cmocka.h']]],
  ['cm_5foutput_5fsubunit_35',['CM_OUTPUT_SUBUNIT',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caa18a2c2a9af66432cf04bf946c7ff9a04',1,'cmocka.h']]],
  ['cm_5foutput_5ftap_36',['CM_OUTPUT_TAP',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caa0504d2b39e4b3114844df1d56212ddb6',1,'cmocka.h']]],
  ['cm_5foutput_5fxml_37',['CM_OUTPUT_XML',['../group__cmocka__config.html#ggab0bc6b8252e7840ff5738477dc7a97caaff2747e671915bc8ef0a018d4b1f243f',1,'cmocka.h']]],
  ['cm_5fprint_5ferror_38',['cm_print_error',['../group__cmocka__config.html#ga5283947dd5e907db7e49e06f27e522c6',1,'cmocka.h']]],
  ['cmcallbacks_39',['CMCallbacks',['../struct_c_m_callbacks.html',1,'']]],
  ['cmfixturefunction_40',['CMFixtureFunction',['../group__cmocka__exec.html#ga6d6219d951a8dd87760353943f045a25',1,'cmocka.h']]],
  ['cmocka_41',['cmocka',['../index.html',1,'']]],
  ['cmocka_20api_42',['📚 The CMocka API',['../group__cmocka.html',1,'']]],
  ['cmocka_20test_43',['A cmocka test',['../index.html#main-test',1,'']]],
  ['cmocka_5fprint_5ferror_44',['cmocka_print_error',['../group__cmocka__config.html#ga72a6204f0ed5d44f2d17b3b0169281b2',1,'cmocka.h']]],
  ['cmocka_5frun_5fgroup_5ftests_45',['cmocka_run_group_tests',['../group__cmocka__exec.html#ga7c62fd0acf2235ce98268c28ee262a57',1,'cmocka.h']]],
  ['cmocka_5frun_5fgroup_5ftests_5fname_46',['cmocka_run_group_tests_name',['../group__cmocka__exec.html#gae9d5f9af521ba6828081ea3014427569',1,'cmocka.h']]],
  ['cmocka_5fset_5fcallbacks_47',['cmocka_set_callbacks',['../group__cmocka__config.html#ga64d0bfeb072aa6735fad5db295f24f29',1,'cmocka_set_callbacks(const struct CMCallbacks *f_callbacks):&#160;cmocka.c'],['../group__cmocka__config.html#ga64d0bfeb072aa6735fad5db295f24f29',1,'cmocka_set_callbacks(const struct CMCallbacks *f_callbacks):&#160;cmocka.c']]],
  ['cmocka_5fset_5fmessage_5foutput_48',['cmocka_set_message_output',['../group__cmocka__config.html#ga003469ffcfe585b9cd058d18ba9a2971',1,'cmocka_set_message_output(uint32_t output):&#160;cmocka.c'],['../group__cmocka__config.html#ga003469ffcfe585b9cd058d18ba9a2971',1,'cmocka_set_message_output(uint32_t output):&#160;cmocka.c']]],
  ['cmocka_5fset_5fskip_5ffilter_49',['cmocka_set_skip_filter',['../group__cmocka__config.html#gac3994cdf617401dee7b0923503621072',1,'cmocka_set_skip_filter(const char *pattern):&#160;cmocka.c'],['../group__cmocka__config.html#gac3994cdf617401dee7b0923503621072',1,'cmocka_set_skip_filter(const char *pattern):&#160;cmocka.c']]],
  ['cmocka_5fset_5ftest_5ffilter_50',['cmocka_set_test_filter',['../group__cmocka__config.html#gad5006b3adbbe8962a57579f1d182a3b8',1,'cmocka_set_test_filter(const char *pattern):&#160;cmocka.c'],['../group__cmocka__config.html#gad5006b3adbbe8962a57579f1d182a3b8',1,'cmocka_set_test_filter(const char *pattern):&#160;cmocka.c']]],
  ['cmocka_5funit_5ftest_51',['cmocka_unit_test',['../group__cmocka__exec.html#ga562719c550b5ce277aab6b0371f7f34f',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fprestate_52',['cmocka_unit_test_prestate',['../group__cmocka__exec.html#ga4d54508b0b7150afb27b4da38f0015c6',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fprestate_5fsetup_5fteardown_53',['cmocka_unit_test_prestate_setup_teardown',['../group__cmocka__exec.html#ga07ea44503d0f6c84c460b4a878cf31d5',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fsetup_54',['cmocka_unit_test_setup',['../group__cmocka__exec.html#gaaccacc105038e49462888a3ededa28c5',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fsetup_5fteardown_55',['cmocka_unit_test_setup_teardown',['../group__cmocka__exec.html#gab9e5396c9a424ccbb5d30e6d421fd066',1,'cmocka.h']]],
  ['cmocka_5funit_5ftest_5fteardown_56',['cmocka_unit_test_teardown',['../group__cmocka__exec.html#ga9b0d5ed78ddeba6d9aaa9a692cda426b',1,'cmocka.h']]],
  ['cmocka_5fversion_57',['CMOCKA_VERSION',['../group__cmocka__version.html#ga900c8ec8466f621a1a19a497eb532aba',1,'cmocka_version.h']]],
  ['cmocka_5fversion_5fint_58',['CMOCKA_VERSION_INT',['../group__cmocka__version.html#gac343098e82585199ce9ec9d20ce64efb',1,'cmocka_version.h']]],
  ['cmocka_5fversion_5fmajor_59',['CMOCKA_VERSION_MAJOR',['../group__cmocka__version.html#ga28751152cf4d96d93bb60011a049641f',1,'cmocka_version.h']]],
  ['cmocka_5fversion_5fmicro_60',['CMOCKA_VERSION_MICRO',['../group__cmocka__version.html#ga047fa873bfb3978348f2fb1c02e18a24',1,'cmocka_version.h']]],
  ['cmocka_5fversion_5fminor_61',['CMOCKA_VERSION_MINOR',['../group__cmocka__version.html#ga74bb0bea61e3f4d68ea1dbe9afb640e4',1,'cmocka_version.h']]],
  ['cmockavaluedata_62',['CMockaValueData',['../group__cmocka__param.html#autotoc_md3',1,'Accessing Values in CMockaValueData'],['../union_c_mocka_value_data.html',1,'CMockaValueData']]],
  ['cmunittest_63',['CMUnitTest',['../struct_c_m_unit_test.html',1,'']]],
  ['cmunittestfunction_64',['CMUnitTestFunction',['../group__cmocka__exec.html#gaf7ec001f0be4727694546526a804c18c',1,'cmocka.h']]],
  ['cmunitteststate_65',['CMUnitTestState',['../struct_c_m_unit_test_state.html',1,'']]],
  ['configuration_20and_20output_66',['🔧 Configuration and Output',['../group__cmocka__config.html',1,'']]],
  ['const_5fptr_67',['const_ptr',['../union_c_mocka_value_data.html#a6e3ba137c0254c08208d53aa269a4c07',1,'CMockaValueData']]]
];
